#
# spec file for package vkquake
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017 Luke Jones <luke.nukem.jones@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vkquake
Version:        1.04.1
Release:        lp152.1.2
Summary:        Quake 1 port using Vulkan instead of OpenGL for rendering
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/Novum/vkQuake
Source:         https://github.com/Novum/vkQuake/archive/%{version}/vkQuake-%{version}.tar.gz
Source99:       %{name}.changes
Source100:      appdata.xml
Source101:      %{name}.desktop
BuildRequires:  pkgconfig
BuildRequires:  vulkan-devel
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)

%description
vkQuake is a Quake 1 port using Vulkan instead of OpenGL for rendering. It is based on the popular QuakeSpasm port and runs all mods compatible with it like Arcane Dimensions or In The Shadows.
Game data must be placed in ~/.vkquake/id1 .

%prep
%setup -q -n vkQuake-%{version}

%if 0%{?sle_version} < 150200
sed -i 's#vulkan_core.h#vulkan.h#' Quake/quakedef.h
%endif

# Drop pre-compiled Windows stuff
rm Windows -fr

# Fix usage of __DATE__ and __TIME__ macros to prevent build in excess
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" Quake/host.c

%build
%make_build -C Quake \
    STRIP=": do not strip:" \
    DO_USERDIRS=1 \
    USE_SDL2=1 \
    USE_CODEC_FLAC=1 \
    USE_CODEC_OPUS=1 \
    USE_CODEC_MIKMOD=1 \
    USE_CODEC_UMX=1 \
    USE_CODEC_MP3=0
%make_build -C Misc/vq_pak

%install
install -Dm755 Quake/vkquake %{buildroot}%{_bindir}/%{name}
install -Dm644 Misc/vq_pak/vkquake.pak %{buildroot}%{_datadir}/games/%{name}/%{name}.pak
install -D -p -m 644 Misc/vkQuake_512.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -p -m 644 %{SOURCE100} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -D -p -m 644 %{SOURCE101} %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license LICENSE.txt
%doc readme.md Misc/fitzquake080.txt Misc/fitzquake080sdl.txt Misc/fitzquake085.txt
%dir %{_datadir}/games/%{name}/
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/games/%{name}/%{name}.pak
%{_datadir}/pixmaps/%{name}.png

%changelog
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.04.1. Changes since 1.02.0:
  * Lots of Vulkan fixes
  * Frame rates over 72 Hz don't break physics anymore
  * Default maximum frame rate raised to 200 Hz.
  * Fix crashes with some Intel drivers and anti aliasing
  * Fix crash "out of dynamic vertex buffer space"
    in some very large custom maps
  * Fix gun position being different than in QuakeSpasm
    when status bar alpha is 0
  * Fixed alpha tested alias models
  * Fixed too large dynamic buffer allocations
  * Lightmaps are now dynamically allocated (from QuakeSpasm)
  * Particles are now rendered as quads instead of triangles
    by default (r_quadparticles) like in QuakeSpasm.
  * Fix alpha tested geo not testing depth
  * Fix issue where wrong push constants were being
    set if render size is smaller than window
  * Fixed certain UI elementes being rendered with alpha
    blending instead of alpha testing like in QS
  * Fix issue with Intel GPUs crashing when leaving full screen
  * Updated to latest QuakeSpasm code
  * Fix particle alpha being affected by fog
* Mon Jun 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.02.0
  + Frame rates over 72 Hz don't break physics anymore (from
    QuakeSpasm spiked)
  + Default maximum frame rate raised to 200 Hz.
  + Fix crashes with some Intel drivers and anti aliasing
  + Fix crash "out of dynamic vertex buffer space" in some very
    large custom maps
  + Fix gun position being different than in QuakeSpasm when status
    bar alpha is 0
  + Other minor Vulkan fixes
- Update to version 1.01.0
  + Extremely large textures should now work
  + Fixed alpha blending issue in some maps
    (e.g. xmasjam2018_bloodshot)
  + Partial support for r_showTris (world and particles)
  + Update to latest QuakeSpasm code
* Sun Oct 14 2018 sean@suspend.net
- Update to 1.00.0
  + Peformance optimizations (use function pointer instead of loader)
  + Compute shader water texture update
  + Update to latest QuakeSpasm code
* Tue Jun 27 2017 luke.nukem.jones@gmail.com
- Update to 0.96.2
  + Fix for AMD hang
- Changes from 0.96.1
  + Bump limits for Arcane Dimensions 1.60 (ad_sepulcher)
  + Fix for broken dynamic lights since version 0.92
  + Add fence between command buffer completion and present
    (required by Vulkan spec)
  + Potential optimization for some drivers: Mark command buffers as
    VK_COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BIT
* Thu Jun 15 2017 boris@steki.net
- update Source url to work as intended
* Tue Jun 13 2017 luke.nukem.jones@gmail.com
- Initial packaging
